==> DBIx-NinjaORM-2.5.0.tar.gz: DBIx-NinjaORM-2.5.0/README.md <==
DBIx-NinjaORM
=============

[![Build Status](https://travis-ci.org/guillaumeaubert/DBIx-NinjaORM.png?branch=master)](https://travis-ci.org/guillaumeaubert/DBIx-NinjaORM)

Flexible Perl ORM for easy transitions from inline SQL to objects.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc DBIx::NinjaORM


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/DBIx-NinjaORM/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/DBIx-NinjaORM)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/DBIx-NinjaORM)

 * [MetaCPAN]
   (https://metacpan.org/release/DBIx-NinjaORM)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2009-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> DBIx-NinjaORM-2.5.1.tar.gz: DBIx-NinjaORM-2.5.1/README.md <==
DBIx-NinjaORM
=============

[![Build Status](https://travis-ci.org/guillaumeaubert/DBIx-NinjaORM.png?branch=master)](https://travis-ci.org/guillaumeaubert/DBIx-NinjaORM)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/DBIx-NinjaORM/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/DBIx-NinjaORM?branch=master)

Flexible Perl ORM for easy transitions from inline SQL to objects.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc DBIx::NinjaORM


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/DBIx-NinjaORM/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/DBIx-NinjaORM)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/DBIx-NinjaORM)

 * [MetaCPAN]
   (https://metacpan.org/release/DBIx-NinjaORM)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2009-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
